.. image:: https://readthedocs.org/projects/annotationframeworkclient/badge/?version=latest
    :target: https://annotationframeworkclient.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

AnnotationFrameworkClient
###########################
This repository supplies client side code to interact with microservices 
in the AnnotationFramework.
